@@ -51,8 +51,6 @@ struct _GgvWindow
         GtkWidget *hbox, *vbox;
         GtkWidget *statusbar;
         GtkWidget *popup_menu;
-        GtkWidget *file_sel;
-        GtkWidget *save_file_sel;
 
         gboolean show_menus, show_sidebar, show_toolbar, show_statusbar;
         gboolean loaded;
